// $Id: DynamicFontParser.js,v 1.1.2.1 2005/06/16 22:49:43 vnagarjuna Exp $ -->

/* ***** BEGIN LICENSE BLOCK ***** 
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Initial Developer of the Original Code is Nagarjuna Venna.
 * Portions created by the Initial Developer are Copyright (C) 2005
 * by the Initial Developer. All Rights Reserved.
 *
 * Contributor(s): Nagarjuna Venna <vnagarjuna@yahoo.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

//Parser for text encoded using dynamic fonts
//1. Remove all unnecessary symbols
//2..Put prefix symbols in the right place 
//3. Break up combo symbols if necessary
//Get this right first, make it fast later

function DynamicFontParser(input, encoding) {
    function removeRedundantSymbols(input, encoding)
    {
        var output = "";
        //1.
        for(var i = 0; i < input.length; ++i) {
            var str = input.substring(i, i + 1);
            if (!encoding.isRedundant(str))
                output += str;
        }
        return output;
    }

    this.index = 0;
    this.text = removeRedundantSymbols(input, encoding);
    this.length = this.text.length;
    this.encoding = encoding;
}

function DynamicFontParser_next()
{
    var response = "";
    this.prefix = "";
    for(var remaining = this.length - this.index; remaining > 0; remaining = this.length - this.index) {
        var maxLookupLen = remaining > this.encoding.maxLookupLen ? this.encoding.maxLookupLen : remaining;
            
        var key = null, value = null;
        for(var i = 1; i <= maxLookupLen; i++) {
            var lookup_key = this.text.substring(this.index, this.index + i);
            //alert("looking up key " + lookup_key);
            var lookup_value = this.encoding.lookup(lookup_key);
            if (lookup_value == null) {
                //alert("No match");
                if (key == null)
                    key = lookup_key;
                continue;
            }
            key = lookup_key;
            value = lookup_value;
            //alert("match for key " + key + " , match = " + value);
            if (!this.encoding.isOverloaded(lookup_key))
                break;
            //alert("key " + lookup_key + " is overloaded");
        }

        var output = this.handleInput(value, key, response, this.encoding.isPrefixSymbol(key));

        if (this.state == Parser.state_PREFIX)
            this.prefix += output;
        else if (this.state == Parser.state_START)
            return output;
        else response = output;
    }

    if (response.length != 0)
        return this.handleConsonantTermination(response);
    return null;
}

function DynamicFontParser_handleConsonantTermination(current)
{
    //3.
    var terminators = "", consnts = "";
    current += this.prefix;
    for(var i = 0; i < current.length; ++i) {
        var type = Padma.getType(current[i]);
        if (type == Padma.type_gunimtam || type == Padma.type_spaccu)
            terminators += current[i];
        else consnts += current[i];
    }

    if (terminators.length == 2) {
        var term1 = terminators[0], term2 = terminators[1];
        if ((term1 == Padma.vowelsn_E && term2 == Padma.vowelsn_AILEN) ||
            (term1 == Padma.vowelsn_AILEN && term2 == Padma.vowelsn_E))
            terminators = Padma.vowelsn_AI;
    }
    return consnts + terminators;
}

//For dynamic fonts, we can recognize that the current syllable is complete only when the next one starts.
function DynamicFontParser_isCurrentSyllableComplete(type)
{
    return false;
}
