// $Id: RTSTransformer.js,v 1.1.2.1 2005/06/13 02:10:30 vnagarjuna Exp $ -->

/* ***** BEGIN LICENSE BLOCK ***** 
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Initial Developer of the Original Code is Nagarjuna Venna.
 * Portions created by the Initial Developer are Copyright (C) 2005
 * by the Initial Developer. All Rights Reserved.
 *
 * Contributor(s): Nagarjuna Venna <vnagarjuna@yahoo.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

//RTS Modes
RTSTransformer.rtsEnglish = 0;
RTSTransformer.rtsTelugu  = 1;


function RTSTransformer(input, output)
{
    this.input = input;
    this.output = output;
    this.rtsMode = Transformer.rtsEnglish;
}

function RTSTransformer_setRTSMode(mode)
{
    if (mode != RTSTransformer.rtsEnglish && mode != RTSTransformer.rtsTelugu)
        return false;
    this.rtsMode = mode;
    return true;
}

function RTSTransformer_parse(text)
{
    var parser = new RTSParser(text);
    var output = "";

    while (parser.more())
        output += this.toOutputFormat(parser.next());

    return output;
}

function RTSTransformer_convert(text)
{
    if (this.rtsMode != RTSTransformer.rtsEnglish && this.rtsMode != RTSTransformer.rtsTelugu) {
        alert("Invalid RTS mode " + this.rtsMode);
        this.rtsMode = 0;
    }

    var output = "";
    var next = 0;

    do {
        var hash = text.indexOf('#', next);
        if (hash == next) {
            hash = text.indexOf('#', hash + 1);
            if (hash != -1) {
                //Mode remains unchanged because we process text between hashes here
                if (this.rtsMode == RTSTransformer.rtsEnglish)
                    output += this.parse(text.substring(next + 1, hash));
                else output += text.substring(next + 1, hash);
            }
            else {
                //mode changes because there is no terminating hash
                if (this.rtsMode == RTSTransformer.rtsEnglish) {
                    this.rtsMode = RTSTransformer.rtsTelugu;
                    output += this.parse(text.substring(next + 1));
                }
                else {
                    this.rtsMode = RTSTransformer.rtsEnglish;
                    output += text.substring(next + 1);
                }
            }
            next = hash + 1;
        }
        //don't change the mode yet because it will be done when it is matched the next time around
        else if (hash != -1) {
            if (this.rtsMode == RTSTransformer.rtsEnglish)
                output += text.substring(next, hash);
            else output += this.parse(text.substring(next, hash));
            next = hash;
        }
        //Mode reamins the same because there are no more hashes
        else {
            if (this.rtsMode == RTSTransformer.rtsEnglish)
                output += text.substring(next);
            else output += this.parse(text.substring(next));
        }
    } while (hash != -1 && hash < text.length);
    //alert(output);
    return output;
}

