// $Id: Transformer.js,v 1.1.2.4 2005/06/17 21:14:26 vnagarjuna Exp $ -->

/* ***** BEGIN LICENSE BLOCK ***** 
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Initial Developer of the Original Code is Nagarjuna Venna.
 * Portions created by the Initial Developer are Copyright (C) 2005
 * by the Initial Developer. All Rights Reserved.
 *
 * Contributor(s): Nagarjuna Venna <vnagarjuna@yahoo.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

//Transformer

//Input/output methods
Transformer.method_RTS      = 0;
Transformer.method_DynFonts = 1;
Transformer.method_Unicode  = 2;
Transformer.method_Unknown  = 3;

//Dynamic fonts supported
Transformer.dynFont_Unknown      = 0;
Transformer.dynFont_Eenadu       = 1;
Transformer.dynFont_ShreeTel0900 = 2;

Transformer.dynFont_name_Eenadu       = "EENADU";
Transformer.dynFont_name_ShreeTel0900 = "SHREE-TEL-0900";

Transformer.padmaDynFontList = new Array();
Transformer.padmaDynFontList[Transformer.dynFont_name_Eenadu]       = Transformer.dynFont_Eenadu ;
Transformer.padmaDynFontList[Transformer.dynFont_name_ShreeTel0900] = Transformer.dynFont_ShreeTel0900;

function Transformer(input, output)
{
    this.input = input;
    this.output = output;
    this.dynFontIndex = Transformer.dynFont_Unknown;
    this.RTSOutputFormat = RTS;
}

Transformer.createTransformer = function (input, output)
{
    if (!Transformer.isValidOutputMethod(output) || !Transformer.isValidInputMethod(input))
        return null;
    if (input == Transformer.method_RTS)
        return new RTSTransformer(input, output);
    return new Transformer(input, output);
}

Transformer.prototype.getInputMethod = function ()
{
    return this.input;
}

Transformer.prototype.getOutputMethod = function ()
{
    return this.output;
}

Transformer.isValidInputMethod = function (method)
{
    return method == Transformer.method_RTS || method == Transformer.method_DynFonts || method == Transformer.method_Unicode 
           || method == Transformer.method_Unknown;
}

Transformer.isValidOutputMethod = function (method)
{
    return method == Transformer.method_RTS || method == Transformer.method_Unicode;
}

Transformer.prototype.convert = function (text)
{
    //Convert to internal format from inputMethod
    var output = "";
    var parser;
    if (this.input == Transformer.method_DynFonts || (this.input == Transformer.method_Unknown && this.dynFontIndex != Transformer.dynFont_Unknown)) {
        if (this.dynFontIndex == Transformer.dynFont_Eenadu)
            parser = new EenaduParser(text);
        else if (this.dynFontIndex == Transformer.dynFont_ShreeTel0900)
            parser = new DynamicFontParser(text, Shree_Tel_0900);
        this.dynFontIndex = Transformer.dynFont_Unknown;
    }
    else if (this.input == Transformer.method_Unicode || this.input == Transformer.method_Unknown) {
        parser = new UnicodeParser(text);
    }

    while (parser.more())
        output += this.toOutputFormat(parser.next());

    return output;
}

Transformer.prototype.toOutputFormat = function (syllable)
{
    var output = "";
    if (this.output == Transformer.method_Unicode) {
        for(var i = 0; i < syllable.length; i++) {
            output += Unicode.transformFromPadma(syllable[i]);
        }
    }
    else if (this.output == Transformer.method_RTS) {
        var last_type = Padma.getType(syllable[syllable.length - 1]);
        if (last_type == Padma.type_hallu || last_type == Padma.type_vattu)
            syllable += Padma.vowel_A;
        for(var i = 0; i < syllable.length; i++)
            output += this.RTSOutputFormat.transformFromPadma(syllable[i]);
    }
    return output;
}

Transformer.isSupportedDynamicFont = function (face)
{
    return Transformer.padmaDynFontList[face.toUpperCase()] != null;
}

Transformer.prototype.setDynamicFont = function (face)
{
    if (this.input != Transformer.method_DynFonts && this.input != Transformer.method_Unknown)
        return false;
    var index = Transformer.padmaDynFontList[face.toUpperCase()];
    if (index == null)
        return false;
    this.dynFontIndex = index;
    return true;
}

Transformer.prototype.setRTSOutputFormat = function (rtsType)
{
    this.RTSOutputFormat = RTS.getOutputFormat(rtsType);
}
